@@ -50,14 +50,21 @@ static const char sccsid[] = "@(#)ant3d.c	5.13 2004/07/23 xlockmore";
 
 #ifdef MODE_ant3d
 
+#define DEF_LABEL "True"
+#define FONT_HEIGHT 19
+#define FONT_WIDTH 15
+
 #define DEF_RULE "A" /* All rules */
 #define DEF_EYES  "False"
 
 static char *rule;
 static Bool eyes;
+static Bool label;
 
 static XrmOptionDescRec opts[] =
 {
+	{(char *) "-label", (char *) ".ant3d.label", XrmoptionNoArg, (caddr_t) "on"},
+	{(char *) "+label", (char *) ".ant3d.label", XrmoptionNoArg, (caddr_t) "off"},
 	{(char *) "-rule", (char *) ".ant3d.rule", XrmoptionSepArg, (caddr_t) NULL},
 	{(char *) "-eyes", (char *) ".ant3d.eyes", XrmoptionNoArg, (caddr_t) "on"}
 ,
@@ -65,11 +72,13 @@ static XrmOptionDescRec opts[] =
 };
 static argtype vars[] =
 {
+	{(void *) & label, (char *) "label", (char *) "Label", (char *) DEF_LABEL, t_Bool},
 	{(void *) & rule, (char *) "rule", (char *) "Rule", (char *) DEF_RULE, t_String},
 	{(void *) & eyes, (char *) "eyes", (char *) "Eyes", (char *) DEF_EYES, t_Bool}
 };
 static OptionStruct desc[] =
 {
+	{(char *) "-/+label", (char *) "turn on/off rule labeling"},
 	{(char *) "-rule string", (char *) "base 4 string for Turk's Ant"},
 	{(char *) "-/+eyes", (char *) "turn on/off eyes"}
 };
@@ -167,6 +176,8 @@ typedef struct {
 	GC          stippledGC;
 	Pixmap      pixmaps[NCOLORS - 1];
 	int         nInvisible;
+	int         labelOffsetX, labelOffsetY;
+	char        ruleString[40];
 } antfarm3dstruct;
 
 /* Coordinate ant moves */
@@ -748,6 +759,8 @@ getTable(ModeInfo * mi, int i)
 		(void) fprintf(stdout,
 			"ants %d, table number %d, colors %d, states %d\n",
 			ap->n, i, ap->ncolors, ap->nstates);
+	if (label)
+		(void) sprintf(ap->ruleString, "table number %d", i);
 	for (j = 0; j < total; j++) {
 		status = &(ap->machine[j]);
 		status->color = *patptr++;
@@ -783,6 +796,8 @@ getTurk(ModeInfo * mi, int logClass, int number)
 		(void) fprintf(stdout,
 			"ants %d, Turk's number 0x%x, colors %d\n",
 			ap->n, number, ap->ncolors);
+	if (label)
+		(void) sprintf(ap->ruleString, "Turk's number 0x%x", number);
 }
 
 static void
@@ -1268,6 +1283,22 @@ DrawScreen(ModeInfo * mi)
 			/* ++count; */
 		}
 	}
+	if (label) {
+		int size = MAX(MIN(MI_WIDTH(mi), MI_HEIGHT(mi)) - 1, 1);
+
+		if (size >= 10 * FONT_WIDTH) {
+			/* hard code these to corners */
+			XSetForeground(display, gc, MI_WHITE_PIXEL(mi));
+			/*XDrawString(display, ap->dbuf, gc,
+				16 + ap->labelOffsetX,
+				16 + ap->labelOffsetY + FONT_HEIGHT,
+				ap->ruleString, strlen(ap->ruleString)); */
+			XDrawString(display, ap->dbuf, gc,
+				16 + ap->labelOffsetX, MI_HEIGHT(mi) - 16 -
+				ap->labelOffsetY - FONT_HEIGHT / 2,
+				ap->ruleString, strlen(ap->ruleString));
+		}
+	}
 	XFlush(display);
 	XCopyArea(display, ap->dbuf, MI_WINDOW(mi), gc,
 		0, 0, ap->width, ap->height, 0, 0);
@@ -1365,6 +1396,8 @@ init_ant3d(ModeInfo * mi)
 	} else {
 		End3D(ap);
 	}
+	ap->labelOffsetX = NRAND(8);
+        ap->labelOffsetY = NRAND(8);
 	parseRule(mi);
 	if (MI_NPIXELS(mi) > 2)
 		for (i = 0; i < (int) ap->ncolors - 1; i++)
