@@ -76,7 +76,6 @@ static const char sccsid[] = "@(#)life3d.c	5.07 2003/01/08 xlockmore";
 #define DEF_LABEL "True"
 #define FONT_HEIGHT 19
 #define FONT_WIDTH 15
-#define FONT_LENGTH 20
 #endif
 #define DEF_SERIAL "False"
 
@@ -1116,7 +1115,7 @@ DrawScreen(ModeInfo * mi)
 			       	lp->labelOffsetY - FONT_HEIGHT / 2,
 				lp->nameString, strlen(lp->nameString));
 		}
-         }
+	}
 	XFlush(display);
 	XCopyArea(display, lp->dbuf, MI_WINDOW(mi), gc,
 		0, 0, lp->width, lp->height, 0, 0);
