@@ -22,7 +22,7 @@ static const char sccsid[] = "@(#)pacman.c	5.00 2000/11/01 xlockmore";
  * other special, indirect and consequential damages.
  *
  * Revision History:
- * 13-May-2002: Added -trackmouse feature thanks to code from 'maze.c'.  
+ * 13-May-2002: Added -trackmouse feature thanks to code from 'maze.c'.
  *		splitted up code into several files.  Retouched AI code, cleaned
  *		up code.
  *  3-May-2002: Added AI to pacman and ghosts, slowed down ghosts.
@@ -70,10 +70,10 @@ static const char sccsid[] = "@(#)pacman.c	5.00 2000/11/01 xlockmore";
 
 #ifdef DISABLE_INTERACTIVE
 ModeSpecOpt pacman_opts = {
-	0, 
-	(XrmOptionDescRec *) NULL, 
-	0, 
-	(argtype *) NULL, 
+	0,
+	(XrmOptionDescRec *) NULL,
+	0,
+	(argtype *) NULL,
 	(OptionStruct *) NULL
 };
 #else
@@ -87,7 +87,7 @@ static XrmOptionDescRec opts[] =
 
 static argtype vars[] =
 {
-	{(caddr_t *) & trackmouse, (char *) "trackmouse", (char *) "TrackMouse",
+	{(void *) & trackmouse, (char *) "trackmouse", (char *) "TrackMouse",
 		(char *) DEF_TRACKMOUSE, t_Bool}
 };
 
@@ -102,7 +102,7 @@ ModeSpecOpt pacman_opts =
 #endif
 
 #ifdef USE_MODULES
-ModStruct   pacman_description = { 
+ModStruct   pacman_description = {
 	"pacman", 		/* *cmdline_arg; */
 	"init_pacman", 		/* *init_name; */
 	"draw_pacman", 		/* *callback_name; */
@@ -135,7 +135,7 @@ free_pacman(Display *display, pacmangamestruct *pp)
 	for (dir = 0; dir < 4; dir++)
 		for (mouth = 0; mouth < MAXMOUTH; mouth++)
 			if (pp->pacmanPixmap[dir][mouth] != None) {
-				XFreePixmap(display, 
+				XFreePixmap(display,
 					pp->pacmanPixmap[dir][mouth]);
 				pp->pacmanPixmap[dir][mouth] = None;
 			}
@@ -169,14 +169,14 @@ check_death(ModeInfo * mi, pacmangamestruct *pp)
 		     (pp->ghosts[ghost].row == pp->pacman.nextrow) &&
 		     (pp->ghosts[ghost].col == pp->pacman.nextcol))) {
 			pp->ghosts[ghost].dead = 1;
-			XSetForeground(display, 
-					     pp->stippledGC, 
+			XSetForeground(display,
+					     pp->stippledGC,
 					     MI_BLACK_PIXEL(mi));
-			XFillRectangle(display, window, 
+			XFillRectangle(display, window,
 					    pp->stippledGC,
-					    pp->ghosts[ghost].cf, 
-					    pp->ghosts[ghost].rf, 
-					    pp->spritexs, 
+					    pp->ghosts[ghost].cf,
+					    pp->ghosts[ghost].rf,
+					    pp->spritexs,
 					    pp->spriteys);
 
 		} else
@@ -202,7 +202,7 @@ repopulate(ModeInfo * mi)
 
 	pp->pacman.row = (LEVHEIGHT + JAILHEIGHT)/2 - i;
 	pp->pacman.col = (LEVWIDTH/2);
-	pp->pacman.nextrow = NOWHERE; 
+	pp->pacman.nextrow = NOWHERE;
 	pp->pacman.nextcol = NOWHERE;
 	pp->pacman.cf = NOWHERE;
 	pp->pacman.rf = NOWHERE;
@@ -243,34 +243,34 @@ repopulate(ModeInfo * mi)
 }
 
 /* Sets the color to the color of a wall. */
-static void 
-setwallcolor(ModeInfo * mi) 
+static void
+setwallcolor(ModeInfo * mi)
 {
 	Display    *display = MI_DISPLAY(mi);
 	pacmangamestruct *pp = &pacmangames[MI_SCREEN(mi)];
 
 	if (MI_NPIXELS(mi) > 2)
-		XSetForeground(display, pp->stippledGC, 
+		XSetForeground(display, pp->stippledGC,
 				MI_PIXEL(mi, BLUE));
 	else
-		XSetForeground(display, pp->stippledGC, 
+		XSetForeground(display, pp->stippledGC,
 				MI_WHITE_PIXEL(mi));
 }
 
 /* Sets the color to the color of a dot. */
-static void 
-setdotcolor(ModeInfo * mi) 
+static void
+setdotcolor(ModeInfo * mi)
 {
 	Display    *display = MI_DISPLAY(mi);
 	pacmangamestruct *pp = &pacmangames[MI_SCREEN(mi)];
 
-	XSetForeground(display, pp->stippledGC, 
+	XSetForeground(display, pp->stippledGC,
 			MI_WHITE_PIXEL(mi));
 }
 
 /* Draws a block in the level at the specified x and y locations. */
 static void
-drawlevelblock(ModeInfo * mi, pacmangamestruct *pp, 
+drawlevelblock(ModeInfo * mi, pacmangamestruct *pp,
 		const unsigned x, const unsigned y)
 {
 	Display    *display = MI_DISPLAY(mi);
@@ -293,14 +293,14 @@ drawlevelblock(ModeInfo * mi, pacmangamestruct *pp,
 				setdotcolor(mi);
 				(void)XDrawPoint(display, window,
 						 pp->stippledGC,
-						 x * pp->xs + pp->xb, 
+						 x * pp->xs + pp->xb,
 						 y * pp->ys + pp->yb);
 				break;
 			default:
 				setwallcolor(mi);
 				(void)XDrawPoint(display, window,
 						 pp->stippledGC,
-						 x * pp->xs + pp->xb, 
+						 x * pp->xs + pp->xb,
 						 y * pp->ys + pp->yb);
 		}
 
@@ -318,18 +318,18 @@ drawlevelblock(ModeInfo * mi, pacmangamestruct *pp,
 				(void)XDrawPoint(display, window,
 						 pp->stippledGC,
 						 x * pp->xs + pp->xb +
-						 pp->xs/2, 
+						 pp->xs/2,
 						 y * pp->ys + pp->yb +
 						 pp->ys/2);
 				break;
 			}
 
 			(void)XDrawArc(display, window, pp->stippledGC,
-				(pp->xs * x) + 
-					(pp->xs / 2) - 
+				(pp->xs * x) +
+					(pp->xs / 2) -
 					(pp->xs > 32 ? (pp->xs / 16) : 1) +
 					pp->xb,
-				(pp->ys * y) + 
+				(pp->ys * y) +
 					(pp->ys / 2) -
 					(pp->ys > 32 ? (pp->ys / 16) : 1) +
 					pp->yb,
@@ -398,7 +398,7 @@ drawlevelblock(ModeInfo * mi, pacmangamestruct *pp,
 /* Draws a complete level. */
 static void
 drawlevel(ModeInfo * mi)
-{ 
+{
 	pacmangamestruct *pp = &pacmangames[MI_SCREEN(mi)];
 	unsigned int x, y;
 
@@ -416,36 +416,36 @@ draw_pacman_sprite(ModeInfo * mi)
 	pacmangamestruct *pp = &pacmangames[MI_SCREEN(mi)];
 	unsigned int dir;
 
-	pp->pacman.cf = pp->pacman.col * pp->xs + pp->pacman.delta.x * 
+	pp->pacman.cf = pp->pacman.col * pp->xs + pp->pacman.delta.x *
 		pp->pacman.cfactor + pp->xb + pp->spritedx;
-	pp->pacman.rf = pp->pacman.row * pp->ys + pp->pacman.delta.y * 
+	pp->pacman.rf = pp->pacman.row * pp->ys + pp->pacman.delta.y *
 		pp->pacman.rfactor + pp->yb + pp->spritedy;
 
 	dir = (ABS(pp->pacman.cfactor) * (2 - pp->pacman.cfactor) +
 	       ABS(pp->pacman.rfactor) * (1 + pp->pacman.rfactor)) % 4;
 
-	XSetForeground(display, pp->stippledGC, 
+	XSetForeground(display, pp->stippledGC,
 			     MI_BLACK_PIXEL(mi));
 	if (pp->pacman.oldcf != NOWHERE && pp->pacman.oldrf != NOWHERE) {
 #ifdef FLASH
 		XFillRectangle(display, window, pp->stippledGC,
-			     pp->pacman.oldcf, pp->pacman.oldrf, 
+			     pp->pacman.oldcf, pp->pacman.oldrf,
 			     pp->spritexs, pp->spriteys);
 #else
-		ERASE_IMAGE(display, window, pp->stippledGC, 
+		ERASE_IMAGE(display, window, pp->stippledGC,
 			    pp->pacman.cf,    pp->pacman.rf,
-			    pp->pacman.oldcf, pp->pacman.oldrf, 
+			    pp->pacman.oldcf, pp->pacman.oldrf,
 			    pp->spritexs, pp->spriteys);
 #endif
 	}
 
-	XSetTSOrigin(display, pp->stippledGC, 
+	XSetTSOrigin(display, pp->stippledGC,
 			   pp->pacman.cf, pp->pacman.rf);
 	if (MI_NPIXELS(mi) > 2)
-		XSetForeground(display, pp->stippledGC, 
+		XSetForeground(display, pp->stippledGC,
 				     MI_PIXEL(mi, YELLOW));
 	else
-		XSetForeground(display, pp->stippledGC, 
+		XSetForeground(display, pp->stippledGC,
 				     MI_WHITE_PIXEL(mi));
 
 	XSetStipple(display, pp->stippledGC,
@@ -453,7 +453,7 @@ draw_pacman_sprite(ModeInfo * mi)
 #ifdef FLASH
 	XSetFillStyle(display, pp->stippledGC, FillStippled);
 #else
-	XSetFillStyle(display, pp->stippledGC, 
+	XSetFillStyle(display, pp->stippledGC,
 			    FillOpaqueStippled);
 #endif
 	if (pp->xs < 2 || pp->ys < 2)
@@ -461,7 +461,7 @@ draw_pacman_sprite(ModeInfo * mi)
 				pp->pacman.cf, pp->pacman.rf);
 	else
 		XFillRectangle(display, window, pp->stippledGC,
-			       pp->pacman.cf, pp->pacman.rf, 
+			       pp->pacman.cf, pp->pacman.rf,
 			       pp->spritexs, pp->spriteys);
 	pp->pacman.mouthstage += pp->pacman.mouthdirection;
 	if ((pp->pacman.mouthstage >= MAXMOUTH) ||
@@ -480,58 +480,58 @@ draw_ghost_sprite(ModeInfo * mi, const unsigned ghost) {
 	Window      window = MI_WINDOW(mi);
 	pacmangamestruct *pp = &pacmangames[MI_SCREEN(mi)];
 
-	pp->ghosts[ghost].cf = 
-		pp->ghosts[ghost].col * pp->xs + pp->ghosts[ghost].delta.x * 
+	pp->ghosts[ghost].cf =
+		pp->ghosts[ghost].col * pp->xs + pp->ghosts[ghost].delta.x *
 		pp->ghosts[ghost].cfactor + pp->xb + pp->spritedx;
-	pp->ghosts[ghost].rf = 
-		pp->ghosts[ghost].row * pp->ys + pp->ghosts[ghost].delta.y * 
+	pp->ghosts[ghost].rf =
+		pp->ghosts[ghost].row * pp->ys + pp->ghosts[ghost].delta.y *
 		pp->ghosts[ghost].rfactor + pp->yb + pp->spritedy;
-	
-	XSetForeground(display, 
-			     pp->stippledGC, 
+
+	XSetForeground(display,
+			     pp->stippledGC,
 			     MI_BLACK_PIXEL(mi));
 
 	if (pp->ghosts[ghost].oldcf != NOWHERE ||
 		pp->ghosts[ghost].oldrf != NOWHERE) {
 #ifdef FLASH
-		XFillRectangle(display, window, 
-				    pp->stippledGC, pp->ghosts[ghost].oldcf, 
-				    pp->ghosts[ghost].oldrf, 
+		XFillRectangle(display, window,
+				    pp->stippledGC, pp->ghosts[ghost].oldcf,
+				    pp->ghosts[ghost].oldrf,
 				    pp->spritexs, pp->spriteys);
 #else
 		ERASE_IMAGE(display, window, pp->stippledGC,
 			pp->ghosts[ghost].cf, pp->ghosts[ghost].rf,
-			pp->ghosts[ghost].oldcf, pp->ghosts[ghost].oldrf, 
+			pp->ghosts[ghost].oldcf, pp->ghosts[ghost].oldrf,
 			pp->spritexs, pp->spriteys);
 #endif
 	}
 
-	drawlevelblock(mi, pp, 
-		(unsigned int)pp->ghosts[ghost].col, 
+	drawlevelblock(mi, pp,
+		(unsigned int)pp->ghosts[ghost].col,
 		(unsigned int)pp->ghosts[ghost].row);
 
 	XSetTSOrigin(display, pp->stippledGC,
 		pp->ghosts[ghost].cf, pp->ghosts[ghost].rf);
 
 	if (MI_NPIXELS(mi) > 2)
-		XSetForeground(display, 
-		     pp->stippledGC, 
+		XSetForeground(display,
+		     pp->stippledGC,
 		     MI_PIXEL(mi, GREEN));
 	else
-		XSetForeground(display, 
-		     pp->stippledGC, 
+		XSetForeground(display,
+		     pp->stippledGC,
 		     MI_WHITE_PIXEL(mi));
 
-	XSetStipple(display, pp->stippledGC, 
+	XSetStipple(display, pp->stippledGC,
 			  pp->ghostPixmap);
 
 #ifdef FLASH
-	XSetFillStyle(display, 
-			    pp->stippledGC, 
+	XSetFillStyle(display,
+			    pp->stippledGC,
 			    FillStippled);
 #else
-	XSetFillStyle(display, 
-			    pp->stippledGC, 
+	XSetFillStyle(display,
+			    pp->stippledGC,
 			    FillOpaqueStippled);
 #endif
 	if (pp->xs < 2 || pp->ys < 2)
@@ -539,11 +539,11 @@ draw_ghost_sprite(ModeInfo * mi, const unsigned ghost) {
 				pp->ghosts[ghost].cf,
 				pp->ghosts[ghost].rf);
 	else
-		XFillRectangle(display, 
-				     window, 
+		XFillRectangle(display,
+				     window,
 				     pp->stippledGC,
-				     pp->ghosts[ghost].cf, 
-				     pp->ghosts[ghost].rf, 
+				     pp->ghosts[ghost].cf,
+				     pp->ghosts[ghost].rf,
 				     pp->spritexs, pp->spriteys);
 
 	pp->ghosts[ghost].oldcf = pp->ghosts[ghost].cf;
@@ -583,7 +583,7 @@ init_pacman(ModeInfo * mi)
 	XPoint	    points[9];
 
 	if (pacmangames == NULL) {
-		if ((pacmangames = (pacmangamestruct *) 
+		if ((pacmangames = (pacmangamestruct *)
 					calloc((size_t)MI_NUM_SCREENS(mi),
 					 sizeof (pacmangamestruct))) == NULL)
 			return;
@@ -602,17 +602,17 @@ init_pacman(ModeInfo * mi)
 		MINGRIDSIZE * size > (int)pp->width ||
 		MINGRIDSIZE * size > (int)pp->height) {
 
-		pp->ys = pp->xs = MAX(MIN(pp->width/LEVWIDTH, 
+		pp->ys = pp->xs = MAX(MIN(pp->width/LEVWIDTH,
 				pp->height/LEVHEIGHT), 1);
 	} else {
 		if (size < -MINSIZE)
-			pp->ys = (short)(NRAND( MIN( -size, MAX( MINSIZE, 
-				   MIN( pp->width, pp->height) / MINGRIDSIZE)) 
+			pp->ys = (short)(NRAND( MIN( -size, MAX( MINSIZE,
+				   MIN( pp->width, pp->height) / MINGRIDSIZE))
 					- MINSIZE + 1) + MINSIZE);
 		else if (size < MINSIZE)
 			pp->ys = MINSIZE;
 		else
-			pp->ys = (short)(MIN(size, 
+			pp->ys = (short)(MIN(size,
 				     MAX(MINSIZE, MIN(pp->width, pp->height) /
 					  MINGRIDSIZE)));
 		pp->xs = pp->ys;
@@ -688,15 +688,15 @@ init_pacman(ModeInfo * mi)
 	if (pp->pacmanPixmap[0][0] != None)
 		for (dir = 0; dir < 4; dir++)
 			for (mouth = 0; mouth < MAXMOUTH; mouth++)
-				XFreePixmap(display, 
+				XFreePixmap(display,
 						  pp->pacmanPixmap[dir]
 						  	[mouth]);
 
 	for (dir = 0; dir < 4; dir++)
 		for (mouth = 0; mouth < MAXMOUTH; mouth++) {
 			if ((pp->pacmanPixmap[dir][mouth] = XCreatePixmap(
-					display, MI_WINDOW(mi), 
-					pp->spritexs, pp->spriteys, 1)) == 
+					display, MI_WINDOW(mi),
+					pp->spritexs, pp->spriteys, 1)) ==
 					None) {
 				free_pacman(display, pp);
 				return;
@@ -710,25 +710,25 @@ init_pacman(ModeInfo * mi)
 			}
 			gcv.foreground = 0;
         		gcv.background = 0;
-			if ((bg_gc = XCreateGC(display, 
+			if ((bg_gc = XCreateGC(display,
 						pp->pacmanPixmap[dir][mouth],
-						GCForeground | 
-						GCBackground, &gcv)) == 
+						GCForeground |
+						GCBackground, &gcv)) ==
 					None) {
         			XFreeGC(display, fg_gc);
 				free_pacman(display, pp);
 				return;
 			}
-			XFillRectangle(display, 
+			XFillRectangle(display,
 					pp->pacmanPixmap[dir][mouth], bg_gc,
 					0, 0, pp->spritexs, pp->spriteys);
 			if (pp->spritexs == 1 && pp->spriteys == 1)
-				XFillRectangle(display, 
-					     pp->pacmanPixmap[dir][mouth], 
-					     fg_gc, 0, 0, pp->spritexs, 
+				XFillRectangle(display,
+					     pp->pacmanPixmap[dir][mouth],
+					     fg_gc, 0, 0, pp->spritexs,
 					     pp->spriteys);
 			else
-				XFillArc(display, 
+				XFillArc(display,
 					       pp->pacmanPixmap[dir][mouth],
 					       fg_gc,
 					0, 0, pp->spritexs, pp->spriteys,
@@ -796,16 +796,16 @@ draw_pacman(ModeInfo * mi)
 	for (g = 0; g < pp->nghosts; g++) {
 		if (pp->ghosts[g].dead == True) continue;
 
-		pp->ghosts[g].err.x = (pp->ghosts[g].err.x + 1) % 
+		pp->ghosts[g].err.x = (pp->ghosts[g].err.x + 1) %
 			pp->ghosts[g].speed;
-		pp->ghosts[g].err.y = (pp->ghosts[g].err.y + 1) % 
+		pp->ghosts[g].err.y = (pp->ghosts[g].err.y + 1) %
 			pp->ghosts[g].speed;
-		pp->ghosts[g].delta.x += pp->ghosts[g].err.x != 0 ? 
+		pp->ghosts[g].delta.x += pp->ghosts[g].err.x != 0 ?
 			pp->incx : 0;
-		pp->ghosts[g].delta.y += pp->ghosts[g].err.y != 0 ? 
+		pp->ghosts[g].delta.y += pp->ghosts[g].err.y != 0 ?
 			pp->incy : 0;
 
-		if (pp->ghosts[g].delta.x >= pp->xs && 
+		if (pp->ghosts[g].delta.x >= pp->xs &&
 		    pp->ghosts[g].delta.y >= pp->ys) {
 			ghost_update(pp, &(pp->ghosts[g]));
 			pp->ghosts[g].delta.x = pp->incx;
