@@ -485,9 +485,11 @@ extern void release_last_mode(ModeInfo *);
 /* -------------------------------------------------------------------- */
 
 /* if you just want the blank mode... how sad! */
-#ifndef BLANK_ONLY 
+#ifndef BLANK_ONLY
+#ifndef NICE_ONLY
 /* comment out following defines to remove modes */
 #ifdef USE_GL
+#define MODE_biof
 #define MODE_cage
 #define MODE_fire
 #define MODE_gears
@@ -506,7 +508,12 @@ extern void release_last_mode(ModeInfo *);
 #ifdef USE_UNSTABLE
 #define MODE_skewb /* under development */
 #endif
+#ifdef USE_RETIRED
+#define MODE_cartoon /* retired mode */
+#define MODE_kaleid2 /* retired mode */
+#endif
 #define MODE_atlantis
+#define MODE_atunnels
 #define MODE_bubble3d
 #define MODE_pipes
 #define MODE_sproingies
@@ -515,8 +522,11 @@ extern void release_last_mode(ModeInfo *);
 #if defined( HAVE_TTF ) && defined( HAVE_GLTT )
 #define MODE_text3d
 #endif
+#if defined( HAVE_FREETYPE ) && defined( HAVE_FTGL )
+#define MODE_text3d2
 #endif
-#endif
+#endif	/* HAVE_CXX */
+#endif	/* USE_GL */
 #ifdef HAVE_CXX
 #define MODE_solitare
 #endif
@@ -528,9 +538,10 @@ extern void release_last_mode(ModeInfo *);
 #define MODE_billiards
 #endif
 #endif
-#endif
-#endif
+#endif	/* UNDER_DEVELOPMENT */
+#endif	/* USE_UNSTABLE */
 #define MODE_ant
+#define MODE_ant3d
 #define MODE_apollonian
 #define MODE_ball
 #define MODE_bat
@@ -562,6 +573,7 @@ extern void release_last_mode(ModeInfo *);
 #define MODE_euler2d
 #define MODE_eyes
 #define MODE_fadeplot
+#define MODE_fiberlamp
 #define MODE_flag
 #define MODE_flame
 #define MODE_flow
@@ -598,6 +610,7 @@ extern void release_last_mode(ModeInfo *);
 #define MODE_pacman
 #define MODE_penrose
 #define MODE_petal
+#define MODE_petri
 #define MODE_polyominoes
 #define MODE_puzzle
 #define MODE_pyro
@@ -621,6 +634,7 @@ extern void release_last_mode(ModeInfo *);
 #define MODE_tetris
 #define MODE_thornbird
 #define MODE_tik_tak
+#define MODE_toneclock
 #define MODE_triangle
 #define MODE_tube
 #define MODE_turtle
@@ -636,7 +650,74 @@ extern void release_last_mode(ModeInfo *);
 #ifdef USE_BOMB
 #define MODE_bomb
 #endif
+
+#else /* NICE_ONLY */
+#ifdef HAVE_CXX
+#define MODE_solitare
 #endif
+#define MODE_apollonian
+#define MODE_blot
+#define MODE_bouboule
+#define MODE_bug
+#define MODE_clock
+#define MODE_daisy
+#define MODE_dclock
+#define MODE_decay
+#define MODE_deco
+#define MODE_demon
+#define MODE_dilemma
+#define MODE_dragon
+#define MODE_eyes
+#define MODE_fadeplot
+#define MODE_flame
+#define MODE_forest
+#define MODE_grav
+#define MODE_hop
+#define MODE_hyper
+#define MODE_ico
+#define MODE_image
+#define MODE_kaleid
+#define MODE_life
+#define MODE_life1d
+#define MODE_life3d
+#define MODE_lightning
+#define MODE_lisa
+#define MODE_lissie
+#define MODE_loop
+#define MODE_marquee
+#define MODE_munch
+#define MODE_nose
+#define MODE_pacman
+#define MODE_penrose
+#define MODE_petal
+#define MODE_puzzle
+#define MODE_pyro
+#define MODE_qix
+#define MODE_roll
+#define MODE_space /* should be combined with star some day */
+#define MODE_sphere
+#define MODE_spiral
+#define MODE_spline
+#define MODE_star
+#define MODE_swarm
+#define MODE_tetris
+#define MODE_triangle
+#define MODE_tube
+#define MODE_turtle
+#define MODE_vines
+#define MODE_wator
+#define MODE_wire
+#define MODE_world
+#define MODE_worm
+#define MODE_xcl
+#define MODE_xjack
+
+#ifdef USE_BOMB
+#define MODE_bomb
+#endif
+
+#endif /* NICE_ONLY */
+#endif /* BLANK_ONLY */
 
 #ifndef USE_MODULES
 
@@ -648,6 +729,14 @@ extern ModeHook refresh_ant;
 extern ModeSpecOpt ant_opts;
 #endif
 
+#ifdef MODE_ant3d
+extern ModeHook init_ant3d;
+extern ModeHook draw_ant3d;
+extern ModeHook release_ant3d;
+extern ModeHook refresh_ant3d;
+extern ModeSpecOpt ant3d_opts;
+#endif
+
 #ifdef MODE_apollonian
 extern ModeHook init_apollonian;
 extern ModeHook draw_apollonian;
@@ -665,6 +754,15 @@ extern ModeHook change_atlantis;
 extern ModeSpecOpt atlantis_opts;
 #endif
 
+#ifdef MODE_atunnels
+extern ModeHook init_atunnels;
+extern ModeHook draw_atunnels;
+extern ModeHook release_atunnels;
+extern ModeHook refresh_atunnels;
+extern ModeHook change_atunnels;
+extern ModeSpecOpt atunnels_opts;
+#endif
+
 #ifdef MODE_ball
 extern ModeHook init_ball;
 extern ModeHook draw_ball;
@@ -681,6 +779,15 @@ extern ModeHook refresh_bat;
 extern ModeSpecOpt bat_opts;
 #endif
 
+#ifdef MODE_biof
+extern ModeHook init_biof;
+extern ModeHook draw_biof;
+extern ModeHook release_biof;
+extern ModeHook refresh_biof;
+extern ModeHook change_fire;
+extern ModeSpecOpt biof_opts;
+#endif
+
 #ifdef MODE_billiards
 extern ModeHook init_billiards;
 extern ModeHook draw_billiards;
@@ -753,6 +860,14 @@ extern ModeHook change_cage;
 extern ModeSpecOpt cage_opts;
 #endif
 
+#ifdef MODE_cartoon
+extern ModeHook init_cartoon;
+extern ModeHook draw_cartoon;
+extern ModeHook release_cartoon;
+extern ModeHook refresh_cartoon;
+extern ModeSpecOpt cartoon_opts;
+#endif
+
 #ifdef MODE_clock
 extern ModeHook init_clock;
 extern ModeHook draw_clock;
@@ -883,6 +998,14 @@ extern ModeHook change_fire;
 extern ModeSpecOpt fire_opts;
 #endif
 
+#ifdef MODE_fiberlamp
+extern ModeHook init_fiberlamp;
+extern ModeHook draw_fiberlamp;
+extern ModeHook release_fiberlamp;
+extern ModeHook change_fiberlamp;
+extern ModeSpecOpt fiberlamp_opts;
+#endif
+
 #ifdef MODE_flag
 extern ModeHook init_flag;
 extern ModeHook draw_flag;
@@ -1014,9 +1137,10 @@ extern ModeSpecOpt invert_opts;
 extern ModeHook init_juggle;
 extern ModeHook draw_juggle;
 extern ModeHook release_juggle;
+extern ModeHook change_juggle;
 extern ModeSpecOpt juggle_opts;
 #endif
- 
+
 #ifdef MODE_julia
 extern ModeHook init_julia;
 extern ModeHook draw_julia;
@@ -1025,6 +1149,14 @@ extern ModeHook refresh_julia;
 extern ModeSpecOpt julia_opts;
 #endif
 
+#ifdef MODE_kaleid2
+extern ModeHook init_kaleid2;
+extern ModeHook draw_kaleid2;
+extern ModeHook release_kaleid2;
+extern ModeHook refresh_kaleid2;
+extern ModeSpecOpt kaleid2_opts;
+#endif
+
 #ifdef MODE_kaleid
 extern ModeHook init_kaleid;
 extern ModeHook draw_kaleid;
@@ -1236,6 +1368,14 @@ extern ModeHook refresh_petal;
 extern ModeSpecOpt petal_opts;
 #endif
 
+#ifdef MODE_petri
+extern ModeHook init_petri;
+extern ModeHook draw_petri;
+extern ModeHook release_petri;
+extern ModeHook refresh_petri;
+extern ModeSpecOpt petri_opts;
+#endif
+
 #ifdef MODE_pipes
 extern ModeHook init_pipes;
 extern ModeHook draw_pipes;
@@ -1493,6 +1633,15 @@ extern ModeHook change_text3d;
 extern ModeSpecOpt text3d_opts;
 #endif
 
+#ifdef MODE_text3d2
+extern ModeHook init_text3d2;
+extern ModeHook draw_text3d2;
+extern ModeHook release_text3d2;
+extern ModeHook refresh_text3d2;
+extern ModeHook change_text3d2;
+extern ModeSpecOpt text3d2_opts;
+#endif
+
 #ifdef MODE_thornbird
 extern ModeHook init_thornbird;
 extern ModeHook draw_thornbird;
@@ -1510,6 +1659,14 @@ extern ModeHook refresh_tik_tak;
 extern ModeSpecOpt tik_tak_opts;
 #endif
 
+#ifdef MODE_toneclock
+extern ModeHook init_toneclock;
+extern ModeHook draw_toneclock;
+extern ModeHook release_toneclock;
+extern ModeHook refresh_toneclock;
+extern ModeSpecOpt toneclock_opts;
+#endif
+
 #ifdef MODE_triangle
 extern ModeHook init_triangle;
 extern ModeHook draw_triangle;
