@@ -1219,7 +1219,10 @@ checkPasswd(char *buffer)
 	(void) seteuid(ruid); /* back to user's privileges */
 #endif
 
+#ifndef GENTOO
+	/* https://bugs.gentoo.org/show_bug.cgi?id=96212 */
 	pam_error = pam_acct_mgmt(pamh, 0);
+#endif
 	if (pam_error == PAM_NEW_AUTHTOK_REQD)
 		pam_error = pam_chauthtok(pamh, PAM_CHANGE_EXPIRED_AUTHTOK);
 	PAM_BAIL;
